==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ru-RU/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'Пользователь принял элемент',
    'acceptance_asset_declined' => 'Пользователь отклонил элемент',
    'a_user_canceled' => 'Пользователь отменил запрос элемента на веб-сайте',
    'a_user_requested' => 'Пользователь запросил элемент на веб-сайте',
    'accessory_name' => 'Аксессуар:',
    'additional_notes' => 'Дополнительные Примечания:',
    'admin_has_created' => 'Администратор создал аккаунт для вас на :web.',
    'asset' => 'Актив:',
    'asset_name' => 'Имя актива:',
    'asset_requested' => 'Актив запрошен',
    'asset_tag' => 'Тег актива',
    'assigned_to' => 'Выдано',
    'best_regards' => 'С наилучшими пожеланиями,',
    'canceled' => 'Отменен:',
    'checkin_date' => 'Дата возврата:',
    'checkout_date' => 'Дата выдачи:',
    'click_to_confirm' => 'Пожалуйста, перейдите по ссылке, чтобы подтвердить ваш :web аккаунт:',
    'click_on_the_link_accessory' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение аксессуара.',
    'click_on_the_link_asset' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение актива.',
    'Confirm_Asset_Checkin' => 'Подтверждение возврата активов',
    'Confirm_Accessory_Checkin' => 'Подтвердить возврат аксессуара',
    'Confirm_accessory_delivery' => 'Подтвердить доставку аксессуара',
    'Confirm_license_delivery' => 'Подтвердите получение лицензии',
    'Confirm_asset_delivery' => 'Подтвердить доставку актива',
    'Confirm_consumable_delivery' => 'Подтвердить доставку расходников',
    'current_QTY' => 'Текущее количество',
    'Days' => 'Дни',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Ожидаемая дата возврата:',
    'expires' => 'Истекает',
    'Expiring_Assets_Report' => 'Отчет об истечении активов.',
    'Expiring_Licenses_Report' => 'Отчет об истечении лицензий.',
    'hello' => 'Привет',
    'hi' => 'Привет',
    'i_have_read' => 'Я прочитал и согласен с условиями использования, и получил этот предмет.',
    'item' => 'Предмет:',
    'Item_Request_Canceled' => 'Запрос предмета отменен',
    'Item_Requested' => 'Предмет запрошен',
    'link_to_update_password' => 'Пожалуйста, перейдите по ссылке, чтобы обновить ваш :web пароль:',
    'login_first_admin' => 'Чтобы войти в Snipe-It используйте следующие логин и пароль:',
    'login' => 'Логин:',
    'Low_Inventory_Report' => 'Отчет о заканчивающихся предметах',
    'inventory_report' => 'Отчет о запасах',
    'min_QTY' => 'Мин Кол-во',
    'name' => 'Название',
    'new_item_checked' => 'Новый предмет был выдан под вашем именем, подробности ниже.',
    'password' => 'Пароль:',
    'password_reset' => 'Сброс пароля',

    'read_the_terms' => 'Пожалуйста, прочитайте условия использования ниже.',
    'read_the_terms_and_click' => 'Пожалуйста, прочитайте условия использования ниже и нажмите на ссылку внизу, чтобы подтвердить, что вы ознакомились и соглашаетесь с условиями использования и получили актив.',
    'requested' => 'Запрошено:',
    'reset_link' => 'Ваша ссылка на сброс пароля',
    'reset_password' => 'Нажмите здесь, чтобы сбросить свой пароль:',
    'serial' => 'Серийный номер',
    'supplier' => 'Поставщик',
    'tag' => 'Метка',
    'test_email' => 'Тестовое сообщение от Snipe-IT',
    'test_mail_text' => 'Это тестовое сообщение от Snipe-IT. Если вы его получили, значит почта работает :)',
    'the_following_item' => 'Данный предмет был возвращен: ',
    'low_inventory_alert' => 'Осталась :count штука, что или уже ниже минимального запаса, или скоро будет ниже.|Осталось :count штук, что или уже ниже минимального запаса, или скоро будет ниже.',
    'assets_warrantee_alert' => 'Имеется :count актив, гарантия на который истечет в следующ(ие/ий) :threshold дней/день.|Имеется :count активов, гарантия на которые истечет в следующ(ие/ий) :threshold дней/день.',
    'license_expiring_alert' => 'Имеется :count лицензия, срок которой истечет в следующ(ие/ий) :threshold дней/день.|Имеются :count лицензии, срок которых истечет в следующ(ие/ий) :threshold дней/день.',
    'to_reset' => 'Чтобы сбросить ваш :web пароль, заполните форму:',
    'type' => 'Тип',
    'upcoming-audits' => ':count активов запланированы для аудита в течение :threshold дней.| :count активов будут запланированы для аудита через :threshold дней.',
    'user' => 'Пользователь',
    'username' => 'Имя пользователя',
    'welcome' => 'Добро пожаловать, :name',
    'welcome_to' => 'Добро пожаловать на :web!',
    'your_credentials' => 'Ваш логин и пароль от Snipe-IT',
    'Accessory_Checkin_Notification' => 'Аксессуар выдан',
    'Asset_Checkin_Notification' => 'Актив принят',
    'Asset_Checkout_Notification' => 'Актив выдан',
    'License_Checkin_Notification' => 'Лицензия выдана',
    'Expected_Checkin_Report' => 'Отчёт запрошенных активов',
    'Expected_Checkin_Notification' => 'Напоминание: приближается крайний срок проверки :name',
    'Expected_Checkin_Date' => 'Актив, выданный вам ранее, должен быть проверен :date дней назад',
    'your_assets' => 'Посмотреть активы',
    'rights_reserved' => 'Все права защищены.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ru-RU/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Аксессуар выдан',
    'Accessory_Checkout_Notification' => 'Аксессуар выведен',
    'Asset_Checkin_Notification' => 'Актив принят',
    'Asset_Checkout_Notification' => 'Актив выдан',
    'Confirm_Accessory_Checkin' => 'Подтвердить возврат аксессуара',
    'Confirm_Asset_Checkin' => 'Подтверждение возврата активов',
    'Confirm_accessory_delivery' => 'Подтвердить доставку аксессуара',
    'Confirm_asset_delivery' => 'Подтвердить доставку актива',
    'Confirm_consumable_delivery' => 'Подтвердить доставку расходников',
    'Confirm_license_delivery' => 'Подтвердите получение лицензии',
    'Consumable_checkout_notification' => 'Расходный материал выведен',
    'Days' => 'Дни',
    'Expected_Checkin_Date' => 'Актив, выданный вам ранее, должен быть проверен :date дней назад',
    'Expected_Checkin_Notification' => 'Напоминание: приближается крайний срок проверки :name',
    'Expected_Checkin_Report' => 'Отчёт запрошенных активов',
    'Expiring_Assets_Report' => 'Отчет об истечении активов.',
    'Expiring_Licenses_Report' => 'Отчет об истечении лицензий.',
    'Item_Request_Canceled' => 'Запрос предмета отменен',
    'Item_Requested' => 'Предмет запрошен',
    'License_Checkin_Notification' => 'Лицензия выдана',
    'License_Checkout_Notification' => 'Лицензия заблокирована',
    'Low_Inventory_Report' => 'Отчет о заканчивающихся предметах',
    'a_user_canceled' => 'Пользователь отменил запрос элемента на веб-сайте',
    'a_user_requested' => 'Пользователь запросил элемент на веб-сайте',
    'acceptance_asset_accepted' => 'Пользователь принял элемент',
    'acceptance_asset_declined' => 'Пользователь отклонил элемент',
    'accessory_name' => 'Аксессуар:',
    'additional_notes' => 'Дополнительные Примечания:',
    'admin_has_created' => 'Администратор создал аккаунт для вас на :web.',
    'asset' => 'Актив:',
    'asset_name' => 'Имя актива:',
    'asset_requested' => 'Актив запрошен',
    'asset_tag' => 'Тег актива',
    'assets_warrantee_alert' => 'Имеется :count актив, гарантия на который истечет в следующ(ие/ий) :threshold дней/день.|Имеется :count активов, гарантия на которые истечет в следующ(ие/ий) :threshold дней/день.',
    'assigned_to' => 'Выдано',
    'best_regards' => 'С наилучшими пожеланиями,',
    'canceled' => 'Отменен:',
    'checkin_date' => 'Дата возврата:',
    'checkout_date' => 'Дата выдачи:',
    'checkedout_from' => 'Отключено от',
    'checkedin_from'  => 'Возврат из',
    'checked_into' => 'Выдано',
    'click_on_the_link_accessory' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение аксессуара.',
    'click_on_the_link_asset' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение актива.',
    'click_to_confirm' => 'Пожалуйста, перейдите по ссылке, чтобы подтвердить ваш :web аккаунт:',
    'current_QTY' => 'Текущее количество',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Ожидаемая дата возврата:',
    'expires' => 'Истекает',
    'hello' => 'Привет',
    'hi' => 'Привет',
    'i_have_read' => 'Я прочитал и согласен с условиями использования, и получил этот предмет.',
    'inventory_report' => 'Отчет о запасах',
    'item' => 'Предмет:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Имеется :count лицензия, срок которой истечет в следующ(ие/ий) :threshold дней/день.|Имеются :count лицензии, срок которых истечет в следующ(ие/ий) :threshold дней/день.',
    'link_to_update_password' => 'Пожалуйста, перейдите по ссылке, чтобы обновить ваш :web пароль:',
    'login' => 'Логин:',
    'login_first_admin' => 'Чтобы войти в Snipe-It используйте следующие логин и пароль:',
    'low_inventory_alert' => 'Осталась :count штука, что или уже ниже минимального запаса, или скоро будет ниже.|Осталось :count штук, что или уже ниже минимального запаса, или скоро будет ниже.',
    'min_QTY' => 'Мин Кол-во',
    'name' => 'Название',
    'new_item_checked' => 'Новый предмет был выдан под вашем именем, подробности ниже.',
    'notes' => 'Заметки',
    'password' => 'Пароль:',
    'password_reset' => 'Сброс пароля',
    'read_the_terms' => 'Пожалуйста, прочитайте условия использования ниже.',
    'read_the_terms_and_click' => 'Пожалуйста, ознакомьтесь с нижеприведёнными условиями использования ПО и нажмите на ссылку внизу, чтобы подтвердить, что и соглашаетесь с условиями использования и получили актив.',
    'requested' => 'Запрошено:',
    'reset_link' => 'Ваша ссылка на сброс пароля',
    'reset_password' => 'Нажмите здесь, чтобы сбросить свой пароль:',
    'rights_reserved' => 'Все права защищены.',
    'serial' => 'Серийный номер',
    'snipe_webhook_test' => 'Тест интеграции Snipe-IT',
    'snipe_webhook_summary' => 'Резюме теста Snipe-IT интеграции',
    'supplier' => 'Поставщик',
    'tag' => 'Метка',
    'test_email' => 'Тестовое сообщение от Snipe-IT',
    'test_mail_text' => 'Это тестовое сообщение от Snipe-IT. Если вы его получили, значит почта работает :)',
    'the_following_item' => 'Данный предмет был возвращен: ',
    'to_reset' => 'Чтобы сбросить ваш :web пароль, заполните форму:',
    'type' => 'Тип',
    'upcoming-audits' => ':count активов запланированы для аудита в течение :threshold дней.| :count активов будут запланированы для аудита через :threshold дней.',
    'user' => 'Пользователь',
    'username' => 'Имя пользователя',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Добро пожаловать, :name',
    'welcome_to' => 'Добро пожаловать на :web!',
    'your_assets' => 'Посмотреть активы',
    'your_credentials' => 'Ваш логин и пароль от Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
